ExternalBufferSerde

Trait ExternalBufferSerde 

pub trait ExternalBufferSerde: Sized {
    // Required methods
    fn into_external_buffer(self) -> Result<Vec<u8>, Error>;
    fn from_external_buffer(value: &[u8]) -> Result<Self, Error>;
}
Convert object into data that can saved in external buffer and vice versa This trait is not necessary if your external use a staroge like sqlite, in which case data store and retrieve without serde.

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> ExternalBufferSerde for T
where T: Encode + Decode<()>,